@@ -1,88 +1,10 @@
-###############################################################################
-#                                                                             #
-#    Copyright © 2012-2013 -- IRB/INSERM                                      #
-#                            (Institut de Recherche en Biothérapie /          #
-#                             Institut National de la Santé et de la          #
-#                             Recherche Médicale)                             #
-#                                                                             #
-#  Auteurs/Authors:  Jerôme AUDOUX <jerome.audoux@univ-montp2.fr>             #
-#                    Nicolas PHILIPPE <nicolas.philippe@inserm.fr>            #
-#                                                                             #
-#  -------------------------------------------------------------------------  #
-#                                                                             #
-#  Ce fichier fait partie de la suite CracTools qui contient plusieurs pipeline# 
-#  intégrés permettant de traiter les évênements biologiques présents dans du #
-#  RNA-Seq. Les CracTools travaillent à partir d'un fichier SAM de CRAC et d'un# 
-#  fichier d'annotation au format GFF3.                                       #
-#                                                                             #
-#  Ce logiciel est régi  par la licence CeCILL  soumise au droit français et  #
-#  respectant les principes  de diffusion des logiciels libres.  Vous pouvez  #
-#  utiliser, modifier et/ou redistribuer ce programme sous les conditions de  #
-#  la licence CeCILL  telle que diffusée par le CEA,  le CNRS et l'INRIA sur  #
-#  le site "http://www.cecill.info".                                          #
-#                                                                             #
-#  En contrepartie de l'accessibilité au code source et des droits de copie,  #
-#  de modification et de redistribution accordés par cette licence, il n'est  #
-#  offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,  #
-#  seule une responsabilité  restreinte pèse  sur l'auteur du programme,  le  #
-#  titulaire des droits patrimoniaux et les concédants successifs.            #
-#                                                                             #
-#  À  cet égard  l'attention de  l'utilisateur est  attirée sur  les risques  #
-#  associés  au chargement,  à  l'utilisation,  à  la modification  et/ou au  #
-#  développement  et à la reproduction du  logiciel par  l'utilisateur étant  #
-#  donné  sa spécificité  de logiciel libre,  qui peut le rendre  complexe à  #
-#  manipuler et qui le réserve donc à des développeurs et des professionnels  #
-#  avertis  possédant  des  connaissances  informatiques  approfondies.  Les  #
-#  utilisateurs  sont donc  invités  à  charger  et  tester  l'adéquation du  #
-#  logiciel  à leurs besoins  dans des conditions  permettant  d'assurer  la  #
-#  sécurité de leurs systêmes et ou de leurs données et,  plus généralement,  #
-#  à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.         #
-#                                                                             #
-#  Le fait  que vous puissiez accéder  à cet en-tête signifie  que vous avez  #
-#  pris connaissance  de la licence CeCILL,  et que vous en avez accepté les  #
-#  termes.                                                                    #
-#                                                                             #
-#  -------------------------------------------------------------------------  #
-#                                                                             #
-#  This file is part of the CracTools which provide several integrated        #
-#  pipeline to analyze biological events present in RNA-Seq data. CracTools   #
-#  work on a SAM file generated by CRAC and an annotation file in GFF3 format.#
-#                                                                             #
-#  This software is governed by the CeCILL license under French law and       #
-#  abiding by the rules of distribution of free software. You can use,        #
-#  modify and/ or redistribute the software under the terms of the CeCILL     #
-#  license as circulated by CEA, CNRS and INRIA at the following URL          #
-#  "http://www.cecill.info".                                                  #
-#                                                                             #
-#  As a counterpart to the access to the source code and rights to copy,      #
-#  modify and redistribute granted by the license, users are provided only    #
-#  with a limited warranty and the software's author, the holder of the       #
-#  economic rights, and the successive licensors have only limited            #
-#  liability.                                                                 #
-#                                                                             #
-#  In this respect, the user's attention is drawn to the risks associated     #
-#  with loading, using, modifying and/or developing or reproducing the        #
-#  software by the user in light of its specific status of free software,     #
-#  that may mean that it is complicated to manipulate, and that also          #
-#  therefore means that it is reserved for developers and experienced         #
-#  professionals having in-depth computer knowledge. Users are therefore      #
-#  encouraged to load and test the software's suitability as regards their    #
-#  requirements in conditions enabling the security of their systems and/or   #
-#  data to be ensured and, more generally, to use and operate it in the same  #
-#  conditions as regards security.                                            #
-#                                                                             #
-#  The fact that you are presently reading this means that you have had       #
-#  knowledge of the CeCILL license and that you accept its terms.             #
-#                                                                             #
-###############################################################################
-
-
 package CracTools::SAMReader::SAMline;
 {
   $CracTools::SAMReader::SAMline::DIST = 'CracTools';
 }
 # ABSTRACT: The object for manipulation a SAM line.
-$CracTools::SAMReader::SAMline::VERSION = '1.08';
+$CracTools::SAMReader::SAMline::VERSION = '1.2';
+
 use strict;
 use warnings;
 use Carp;
@@ -126,6 +48,9 @@ sub new {
     # Hack in case there is multiple field with the same tag
     $extended_fields{$key} = defined $extended_fields{$key}? $extended_fields{$key}.";".$value : $value;
   }
+  
+  # We do not want any "chr" string before the reference sequence value
+  $rname =~ s/^chr//;
 
   my $self = bless{ 
     qname => $qname,
@@ -460,7 +385,7 @@ sub isClassified {
 
 sub events {
   my $self = shift;
-  my $event_type = shift;
+  my $event_type = lc shift;
   $self->loadEvents();#$event_type);
   if(defined $self->{events}{$event_type}) {
     return $self->{events}{$event_type};
@@ -482,10 +407,11 @@ sub loadEvents {
     my @events = split(";",$self->{extended_fields}{XE});
     foreach my $event (@events) {
       my ($event_id,$event_break_id,$event_type,$event_infos) = $event =~ /([^:]+):([^:]+):([^:]+):(.*)/g;
+      $event_type = lc $event_type;
       next if(defined $event_type_to_load && $event_type ne $event_type_to_load);
       if(defined $event_id) {
         my %event_hash;
-        if($event_type eq 'Junction') {
+        if($event_type eq 'junction') {
           my ($type,$pos_read,$loc,$gap) = split(':',$event_infos);
           my ($chr,$pos,$strand) = expandCracLoc($loc);
           %event_hash = ( type => $type,
@@ -493,7 +419,7 @@ sub loadEvents {
                            loc => {chr => $chr, pos => $pos, strand => $strand},
                            gap => $gap,
                          );
-        } elsif($event_type eq 'Ins' || $event_type eq 'Del') {
+        } elsif($event_type eq 'ins' || $event_type eq 'del') {
           my ($score,$pos_read,$loc,$nb) = split(':',$event_infos); 
           my ($chr,$pos,$strand) = expandCracLoc($loc);
           %event_hash = ( score => $score,
@@ -501,7 +427,7 @@ sub loadEvents {
                       loc => {chr => $chr, pos => $pos, strand => $strand},
                       nb => $nb,
                     );
-        } elsif($event_type eq 'SNP') {
+        } elsif($event_type eq 'snp') {
           my ($score,$pos_read,$loc,$expected,$actual) = split(':',$event_infos); 
           my ($chr,$pos,$strand) = expandCracLoc($loc);
           %event_hash = ( score => $score,
@@ -510,7 +436,7 @@ sub loadEvents {
                       expected => $expected,
                       actual => $actual,
                     );
-        } elsif($event_type eq 'Error') {
+        } elsif($event_type eq 'error') {
           my ($type,$pos,$score,$other1,$other2) = split(':',$event_infos); 
           %event_hash = ( score => $score,
                       pos => $pos,
@@ -519,17 +445,19 @@ sub loadEvents {
                       other2 => $other2,
                     );
         } elsif($event_type eq 'chimera') {
-          my ($pos_read,$loc1,$loc2) = split(':',$event_infos); 
+          my ($pos_read,$loc1,$loc2,$class,$score) = split(':',$event_infos); 
           my ($chr1,$pos1,$strand1) = expandCracLoc($loc1);
           my ($chr2,$pos2,$strand2) = expandCracLoc($loc2);
           %event_hash = ( pos => $pos_read,
                       loc1 => {chr => $chr1, pos => $pos1, strand => $strand1},
                       loc2 => {chr => $chr2, pos => $pos2, strand => $strand2},
+                      class => $class,
+                      score => $score,
                     );
-        } elsif($event_type eq 'Undetermined') {
+        } elsif($event_type eq 'undetermined') {
           %event_hash = ( message => $event_infos,
                     );
-        } elsif($event_type eq 'BioUndetermined') {
+        } elsif($event_type eq 'bioundetermined') {
           my ($pos,$message) = $event_infos =~ /([^:]+):(.*)/; 
           %event_hash = ( pos => $pos,
                       message => $message,
@@ -720,7 +648,7 @@ CracTools::SAMReader::SAMline - The object for manipulation a SAM line.
 
 =head1 VERSION
 
-version 1.08
+version 1.2
 
 =head1 SYNOPSIS
 
@@ -1093,20 +1021,24 @@ because creating object in Perl can be long and useless for some purposes.
 
 =item *
 
-Nicolas PHILIPPE <nicolas.philippe@inserm.fr>
+Nicolas PHILIPPE <nphilippe.research@gmail.com>
 
 =item *
 
 Jérôme AUDOUX <jaudoux@cpan.org>
 
+=item *
+
+Sacha BEAUMEUNIER <sacha.beaumeunier@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by IRB/INSERM (Institut de Recherche en Biothérapie / Institut National de la Santé et de la Recherche Médicale).
+This software is Copyright (c) 2015 by IRMB/INSERM (Institute for Regenerative Medecine and Biotherapy / Institut National de la Santé et de la Recherche Médicale) and AxLR/SATT (Lanquedoc Roussilon / Societe d'Acceleration de Transfert de Technologie).
 
 This is free software, licensed under:
 
-  CeCILL FREE SOFTWARE LICENSE AGREEMENT, Version 2.1 dated 2013-06-21
+  The GNU Affero General Public License, Version 3, November 2007
 
 =cut
